==> financial_dataset_preprocessor-0.3.5-py3-none-any.whl: financial_dataset_preprocessor/menu2206_preprocessor/menu2206_consts.py <==

COLUMN_NAMES_MENU2206_PREPROCESSED = ['펀드명', '펀드', '자산', '운용역명', '종목명', '종목', '원화 보유정보: 수량',
       '원화 보유정보: 매매가능수량', '원화 보유정보: 취득단가', '원화 보유정보: 취득액',
       '원화 보유정보: 장부가액', '원화 보유정보: 평가액', '원화 보유정보: 평가손익', '원화 보유정보: 환산손익',
       '원화 보유정보: 총평가손익', '원화 보유정보: 총평가손익률', '원화 보유정보: 미수이자',
       '원화 보유정보: 이자환산손익', '원화 보유정보: 선급비용', '원화 보유정보: 상환손익',
       '외화 보유정보: 취득단가', '외화 보유정보: 취득환율', '외화 보유정보: 외화취득액',
       '외화 보유정보: 외화평가액', '외화 보유정보: 손익률', '외화 보유정보: 미수이자',
       '기능통화 보유정보: 취득단가', '기능통화 보유정보: 취득액', '기능통화 보유정보: 장부가액',
       '기능통화 보유정보: 평가액', '기능통화 보유정보: 평가손익', '기능통화 보유정보: 손익율',
       '기능통화 보유정보: 미수이자', '기능통화 보유정보: 이자환산손익', '기능통화 보유정보: 선급비용',
       '기능통화 보유정보: 환산손익', '비중: 주식/채권', '비중: 자산대비', '비중: 시장대비', '비중: 시장비중',
       '대여정보: 대용/담보수량', '대여정보: 대여수량', '대여정보: 대용비율', '대여정보: 대여비율',
       '평가정보: 종가', '평가정보: 종가증감', '평가정보: 시가수익률', '평가정보: 시가수익률증감',
       '평가정보: 당일환율', '평가정보: 당일환율증감', '종목정보: 표면금리', '종목정보: 할인율',
       '종목정보: 매입수익률', '종목정보: 회계적수익률', '종목정보: 발행일', '종목정보: 만기일',
       '종목정보: 편입일', '종목정보: 업종구분/보증기관', '종목정보: 수정Dur/Beta',
       '종목정보: Duration', '종목정보: 컨벡시티', '종목정보: 신용등급', '종목정보: 잔존일수',
       '종목정보: 표시통화', '종목정보: 옵션행사일', '종목정보: 발행국가', '종목정보: 발행기관',
       '종목정보: 거래소', '종목정보: 상장구분', '자산정보: 순자산', '자산정보: 총자산', '자산정보: 기준가격',
       '자산정보: 증감', '자산정보: ISIN코드', '자산정보: TICKER', '자산정보: 수탁사',
       '자산정보: 자산분류', '자산정보: 지수가중베타', '자산정보: 3사평균', '자산정보: 4사평균',
       '자산정보: KBP가격', '자산정보: NICE가격', '자산정보: KIS가격', '자산정보: FNP가격',
       '자산정보: 3사평균YTM', '자산정보: 4사평균YTM', '자산정보: KBP YTM',
       '자산정보: NICE YTM', '자산정보: KIS YTM', '자산정보: FNP YTM',
       '자산정보: KBP듀레이션', '자산정보: KIS듀레이션', '자산정보: NICE듀레이션',
       '자산정보: FNP듀레이션', '자산정보: KBP컨벡시티', '자산정보: KIS컨벡시티',
       '자산정보: NICE컨벡시티', '자산정보: FNP컨벡시티', '자산정보: 이자지급방법', '자산정보: 시가총액']


COLUMN_NAMES_PREPROCESSED_TOBE_INTEGER_MENU2206 = ['원화 보유정보: 수량', '원화 보유정보: 매매가능수량', '대여정보: 대용/담보수량', '대여정보: 대여수량', '종목정보: 잔존일수']


COLUMN_NAMES_PREPROCESSED_TOBE_NUMBER_MENU2206 = ['원화 보유정보: 취득단가', '원화 보유정보: 취득액',
       '원화 보유정보: 장부가액', '원화 보유정보: 평가액', '원화 보유정보: 평가손익', '원화 보유정보: 환산손익',
       '원화 보유정보: 총평가손익', '원화 보유정보: 총평가손익률', '원화 보유정보: 미수이자',
       '원화 보유정보: 이자환산손익', '원화 보유정보: 선급비용', '원화 보유정보: 상환손익',
       '외화 보유정보: 취득단가', '외화 보유정보: 취득환율', '외화 보유정보: 외화취득액',
       '외화 보유정보: 외화평가액', '외화 보유정보: 손익률', '외화 보유정보: 미수이자',
       '기능통화 보유정보: 취득단가', '기능통화 보유정보: 취득액', '기능통화 보유정보: 장부가액',
       '기능통화 보유정보: 평가액', '기능통화 보유정보: 평가손익', '기능통화 보유정보: 손익율',
       '기능통화 보유정보: 미수이자', '기능통화 보유정보: 이자환산손익', '기능통화 보유정보: 선급비용',
       '기능통화 보유정보: 환산손익', '비중: 주식/채권', '비중: 자산대비', '비중: 시장대비', '비중: 시장비중',
       '대여정보: 대용비율', '대여정보: 대여비율',
       '평가정보: 종가', '평가정보: 종가증감', '평가정보: 시가수익률', '평가정보: 시가수익률증감',
       '평가정보: 당일환율', '평가정보: 당일환율증감', '종목정보: 표면금리', '종목정보: 할인율',
       '종목정보: 매입수익률', '종목정보: 회계적수익률', '종목정보: 업종구분/보증기관', '종목정보: 수정Dur/Beta',
       '종목정보: Duration', '종목정보: 컨벡시티', '종목정보: 신용등급',
       '종목정보: 표시통화', '종목정보: 옵션행사일', '종목정보: 발행국가', '종목정보: 발행기관',
       '종목정보: 거래소', '종목정보: 상장구분', '자산정보: 순자산', '자산정보: 총자산', '자산정보: 기준가격',
       '자산정보: 증감', '자산정보: 지수가중베타', '자산정보: 3사평균', '자산정보: 4사평균',
       '자산정보: KBP가격', '자산정보: NICE가격', '자산정보: KIS가격', '자산정보: FNP가격',
       '자산정보: 3사평균YTM', '자산정보: 4사평균YTM', '자산정보: KBP YTM',
       '자산정보: NICE YTM', '자산정보: KIS YTM', '자산정보: FNP YTM',
       '자산정보: KBP듀레이션', '자산정보: KIS듀레이션', '자산정보: NICE듀레이션',
       '자산정보: FNP듀레이션', '자산정보: KBP컨벡시티', '자산정보: KIS컨벡시티',
       '자산정보: NICE컨벡시티', '자산정보: FNP컨벡시티', '자산정보: 시가총액']

==> financial_dataset_preprocessor-0.3.9-py3-none-any.whl: financial_dataset_preprocessor/menu2206_preprocessor/menu2206_consts.py <==

COLUMN_NAMES_MENU2206_PREPROCESSED = ['펀드명', '펀드', '자산', '운용역명', '종목명', '종목', '원화 보유정보: 수량',
       '원화 보유정보: 매매가능수량', '원화 보유정보: 취득단가', '원화 보유정보: 취득액',
       '원화 보유정보: 장부가액', '원화 보유정보: 평가액', '원화 보유정보: 평가손익', '원화 보유정보: 환산손익',
       '원화 보유정보: 총평가손익', '원화 보유정보: 총평가손익률', '원화 보유정보: 미수이자',
       '원화 보유정보: 이자환산손익', '원화 보유정보: 선급비용', '원화 보유정보: 상환손익',
       '외화 보유정보: 취득단가', '외화 보유정보: 취득환율', '외화 보유정보: 외화취득액',
       '외화 보유정보: 외화평가액', '외화 보유정보: 손익률', '외화 보유정보: 미수이자',
       '기능통화 보유정보: 취득단가', '기능통화 보유정보: 취득액', '기능통화 보유정보: 장부가액',
       '기능통화 보유정보: 평가액', '기능통화 보유정보: 평가손익', '기능통화 보유정보: 손익율',
       '기능통화 보유정보: 미수이자', '기능통화 보유정보: 이자환산손익', '기능통화 보유정보: 선급비용',
       '기능통화 보유정보: 환산손익', '비중: 주식/채권', '비중: 자산대비', '비중: 시장대비', '비중: 시장비중',
       '대여정보: 대용/담보수량', '대여정보: 대여수량', '대여정보: 대용비율', '대여정보: 대여비율',
       '평가정보: 종가', '평가정보: 종가증감', '평가정보: 시가수익률', '평가정보: 시가수익률증감',
       '평가정보: 당일환율', '평가정보: 당일환율증감', '종목정보: 표면금리', '종목정보: 할인율',
       '종목정보: 매입수익률', '종목정보: 회계적수익률', '종목정보: 발행일', '종목정보: 만기일',
       '종목정보: 편입일', '종목정보: 업종구분/보증기관', '종목정보: 수정Dur/Beta',
       '종목정보: Duration', '종목정보: 컨벡시티', '종목정보: 신용등급', '종목정보: 잔존일수',
       '종목정보: 표시통화', '종목정보: 옵션행사일', '종목정보: 발행국가', '종목정보: 발행기관',
       '종목정보: 거래소', '종목정보: 상장구분', '자산정보: 순자산', '자산정보: 총자산', '자산정보: 기준가격',
       '자산정보: 증감', '자산정보: ISIN코드', '자산정보: TICKER', '자산정보: 수탁사',
       '자산정보: 자산분류', '자산정보: 지수가중베타', '자산정보: 3사평균', '자산정보: 4사평균',
       '자산정보: KBP가격', '자산정보: NICE가격', '자산정보: KIS가격', '자산정보: FNP가격',
       '자산정보: 3사평균YTM', '자산정보: 4사평균YTM', '자산정보: KBP YTM',
       '자산정보: NICE YTM', '자산정보: KIS YTM', '자산정보: FNP YTM',
       '자산정보: KBP듀레이션', '자산정보: KIS듀레이션', '자산정보: NICE듀레이션',
       '자산정보: FNP듀레이션', '자산정보: KBP컨벡시티', '자산정보: KIS컨벡시티',
       '자산정보: NICE컨벡시티', '자산정보: FNP컨벡시티', '자산정보: 이자지급방법', '자산정보: 시가총액']


COLUMN_NAMES_PREPROCESSED_TOBE_INTEGER_MENU2206 = ['원화 보유정보: 수량', '원화 보유정보: 매매가능수량', '대여정보: 대용/담보수량', '대여정보: 대여수량', '종목정보: 잔존일수']


COLUMN_NAMES_PREPROCESSED_TOBE_NUMBER_MENU2206 = ['원화 보유정보: 취득단가', '원화 보유정보: 취득액',
       '원화 보유정보: 장부가액', '원화 보유정보: 평가액', '원화 보유정보: 평가손익', '원화 보유정보: 환산손익',
       '원화 보유정보: 총평가손익', '원화 보유정보: 총평가손익률', '원화 보유정보: 미수이자',
       '원화 보유정보: 이자환산손익', '원화 보유정보: 선급비용', '원화 보유정보: 상환손익',
       '외화 보유정보: 취득단가', '외화 보유정보: 취득환율', '외화 보유정보: 외화취득액',
       '외화 보유정보: 외화평가액', '외화 보유정보: 손익률', '외화 보유정보: 미수이자',
       '기능통화 보유정보: 취득단가', '기능통화 보유정보: 취득액', '기능통화 보유정보: 장부가액',
       '기능통화 보유정보: 평가액', '기능통화 보유정보: 평가손익', '기능통화 보유정보: 손익율',
       '기능통화 보유정보: 미수이자', '기능통화 보유정보: 이자환산손익', '기능통화 보유정보: 선급비용',
       '기능통화 보유정보: 환산손익', '비중: 주식/채권', '비중: 자산대비', '비중: 시장대비', '비중: 시장비중',
       '대여정보: 대용비율', '대여정보: 대여비율',
       '평가정보: 종가', '평가정보: 종가증감', '평가정보: 시가수익률', '평가정보: 시가수익률증감',
       '평가정보: 당일환율', '평가정보: 당일환율증감', '종목정보: 표면금리', '종목정보: 할인율',
       '종목정보: 매입수익률', '종목정보: 회계적수익률', '종목정보: 수정Dur/Beta',
       '종목정보: Duration', '종목정보: 컨벡시티', '종목정보: 신용등급',
       '종목정보: 표시통화', '종목정보: 옵션행사일', '종목정보: 발행국가', '종목정보: 발행기관',
       '종목정보: 거래소', '종목정보: 상장구분', '자산정보: 순자산', '자산정보: 총자산', '자산정보: 기준가격',
       '자산정보: 증감', '자산정보: 지수가중베타', '자산정보: 3사평균', '자산정보: 4사평균',
       '자산정보: KBP가격', '자산정보: NICE가격', '자산정보: KIS가격', '자산정보: FNP가격',
       '자산정보: 3사평균YTM', '자산정보: 4사평균YTM', '자산정보: KBP YTM',
       '자산정보: NICE YTM', '자산정보: KIS YTM', '자산정보: FNP YTM',
       '자산정보: KBP듀레이션', '자산정보: KIS듀레이션', '자산정보: NICE듀레이션',
       '자산정보: FNP듀레이션', '자산정보: KBP컨벡시티', '자산정보: KIS컨벡시티',
       '자산정보: NICE컨벡시티', '자산정보: FNP컨벡시티', '자산정보: 시가총액']
